You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by ek...@apache.org on 2005/05/13 04:36:32 UTC

svn commit: r169920 [1/2] - in /incubator/beehive/trunk/samples/petstoreWeb: ./ src/org/apache/beehive/samples/petstore/controls/ src/org/apache/beehive/samples/petstore/controls/data/ src/org/apache/beehive/samples/petstore/resources/ test-src/org/apache/beehive/samples/petstore/test/ web/ web/WEB-INF/tags/beehive/petstore/ web/account/addresses/ web/account/create/ web/account/edit/ web/auth/ web/checkout/ web/search/ web/shop/ web/site/ web/webappRoot/

Author: ekoneil
Date: Thu May 12 19:36:31 2005
New Revision: 169920

URL: http://svn.apache.org/viewcvs?rev=169920&view=rev
Log:
Changes from Scott Semyan.  Adds CSS cleanup and test changes to the petstoreWeb sample app.

BB: self
DRT: Beehive pass / build.dist pass


Added:
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag   (with props)
    incubator/beehive/trunk/samples/petstoreWeb/web/site/categoryMenu.jsp   (with props)
Modified:
    incubator/beehive/trunk/samples/petstoreWeb/build-dist.xml
    incubator/beehive/trunk/samples/petstoreWeb/build.xml
    incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControl.java
    incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControlImpl.java
    incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyCatalogDBControl.java
    incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyOrderDao.java
    incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/resources/view.properties
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Address.java
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/AllTests.java
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Cart.java
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Checkout.java
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Navigation.java
    incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/SignIn.java
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/catalogNav.tag
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/categoryNavHeader.tag
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/headerMenu.tag
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/orderSummary.tag
    incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/productFavorites.tag
    incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/createUpdate.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/listAddresses.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/account/create/create.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/edit.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/listOrders.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/auth/Controller.java
    incubator/beehive/trunk/samples/petstoreWeb/web/auth/login.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/auth/loginError.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/checkout/confirm.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/checkout/newOrder.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/checkout/viewCart.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/checkout/viewOrder.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/index.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/search/index.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/shop/cart.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/shop/category.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/shop/index.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/shop/item.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/shop/product.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/site/default.css
    incubator/beehive/trunk/samples/petstoreWeb/web/site/template.jsp
    incubator/beehive/trunk/samples/petstoreWeb/web/webappRoot/SharedFlow.java

Modified: incubator/beehive/trunk/samples/petstoreWeb/build-dist.xml
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/build-dist.xml?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/build-dist.xml (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/build-dist.xml Thu May 12 19:36:31 2005
@@ -160,7 +160,8 @@
         <delete dir="${testclasses.dir}"/>
     </target>
 
-    <target name="test.run" depends="ensure.httpunit" description="Run the HTTPUnit tests against the petstore">
+    <target name="test.run" depends="ensure.httpunit,test.build" 
+            description="Run the HTTPUnit tests against the petstore">
         <junit fork="yes" haltonfailure="yes" printsummary="yes">
             <formatter type="plain" usefile="false"/>
             <classpath>

Modified: incubator/beehive/trunk/samples/petstoreWeb/build.xml
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/build.xml?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/build.xml (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/build.xml Thu May 12 19:36:31 2005
@@ -70,7 +70,7 @@
     <!-- build - build the webapp                  -->
     <!-- ========================================= -->
 
-    <target name="build" description="Build the webapp">
+    <target name="build" depends="deploy-beehive" description="Build the webapp">
         <copy todir="${build.dir}/">
             <fileset dir="${web.dir}">
                 <exclude name="**/*.java"/>
@@ -184,7 +184,8 @@
         <delete dir="${testclasses.dir}"/>
     </target>
 
-    <target name="test.run" depends="ensure.httpunit" description="Run the HTTPUnit tests against the petstore">
+    <target name="test.run" depends="ensure.httpunit,test.build" 
+            description="Run the HTTPUnit tests against the petstore">
         <junit fork="yes" haltonfailure="yes" printsummary="yes">
             <formatter type="plain" usefile="false"/>
             <classpath>

Modified: incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControl.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControl.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControl.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControl.java Thu May 12 19:36:31 2005
@@ -27,7 +27,7 @@
 @ControlInterface
     public interface AccountControl {
 
-    public Account getAccount(String userId) throws InvalidIdentifierException;
+    public Account getAccount(String userId) throws NoSuchAccountException;
     public void insertAccount(Account account) throws InvalidIdentifierException, AccountAlreadyExistsException;
     public void updateAccount(Account account) throws InvalidIdentifierException, NoSuchAccountException;
     public boolean checkAccountExists(String userId);

Modified: incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControlImpl.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControlImpl.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControlImpl.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/AccountControlImpl.java Thu May 12 19:36:31 2005
@@ -37,15 +37,15 @@
 		return _accountDao.checkAccountExists(key);
     }
 
-    public Account getAccount(String key) throws InvalidIdentifierException
+    public Account getAccount(String key) throws NoSuchAccountException
     {
         if (!checkAccountExists(key))
-            throw new InvalidIdentifierException("no Account found for userId: " + key);
+            throw new NoSuchAccountException("no Account found for userId: " + key);
 
 		Account acct = new Account();
 		acct = _accountDao.getAccountById(key);
 		if (acct.getUserId() == null)
-			throw new InvalidIdentifierException("no Account found for userId: " + key);
+			throw new NoSuchAccountException("no Account found for userId: " + key);
 		return acct;
     }
 

Modified: incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyCatalogDBControl.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyCatalogDBControl.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyCatalogDBControl.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyCatalogDBControl.java Thu May 12 19:36:31 2005
@@ -58,7 +58,7 @@
     public Item getItem(String itemId) throws SQLException;
 
 	// updateItemQuantity
-    @SQL(statement="update Items set inventoryQuantity = {quantity} where itemId = {itemId}")
+    @SQL(statement="update Items set inventoryQuantity = inventoryQuantity - {quantity} where itemId = {itemId}")
     public void updateItemQuantity(String itemId, int quantity) throws SQLException;
 
 	// searchProductList

Modified: incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyOrderDao.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyOrderDao.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyOrderDao.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/controls/data/DerbyOrderDao.java Thu May 12 19:36:31 2005
@@ -78,6 +78,8 @@
 				_dbControl.addOrderItem(orderId, lineItem.getItem().getItemId(), lineItem.getQuantity());
 	        }
 			connection.commit();
+			connection.setAutoCommit( true );
+
 		} catch (SQLException e) {
             _logger.error( "Unexpected DAO exception", e );
 			throw new DataStoreException("unexpected database exception");

Modified: incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/resources/view.properties
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/resources/view.properties?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/resources/view.properties (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/src/org/apache/beehive/samples/petstore/resources/view.properties Thu May 12 19:36:31 2005
@@ -2,7 +2,7 @@
 # checkout / shop
 #
 mainMenuLabel=Main Menu
-confirmMessage=Please confirm the information below and then press continue...
+confirmMessage=Please confirm the information below and then click continue...
 paymentDetailsLabel=Payment Details
 cardTypeLabel=Card type
 cardNumberLabel=Card number
@@ -21,6 +21,8 @@
 shipToDifferentAddressMessage=Ship to different address...
 billingAddressLabel=Billing Address
 shippingAddressLabel=Shipping Address
+billingLabel=Billing
+shippingLabel=Shipping
 
 newOrderLabel=New Order
 orderNumberLabel=Order Number
@@ -62,12 +64,14 @@
 petFavoritesLabel=Pet Favorites
 shopForFavoritesLabel=Shop for more of your favorite pets here
 welcomeLabel=Welcome
+continueLabel=Continue Shopping
 
 userInformation=User Information
 
 orderId=Order ID
 orderDate=Order Date
 orderPrice=Order Price
+orderDetails=Order Details
 
 myOrders=My Orders
 
@@ -91,6 +95,8 @@
 #
 enterTheStore=Enter the Store
 welcome=Welcome to the Beehive Pet Store!
+welcomeTitle=Welcome
+homeTitle=Home
 
 fishCategory=Fish
 dogsCategory=Dogs
@@ -120,3 +126,5 @@
 buttonUpdate=Update
 buttonInsert=Insert
 buttonCancel=Cancel
+newAddress=New Address
+editAddress=Edit Address
\ No newline at end of file

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Address.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Address.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/AllTests.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/AllTests.java Thu May 12 19:36:31 2005
@@ -33,7 +33,7 @@
 		suite.addTestSuite(Search.class);
 		suite.addTestSuite(SignIn.class);
 		suite.addTestSuite(Account.class);
-		suite.addTestSuite(Address.class);
+		suite.addTestSuite(Address.class); 
 		suite.addTestSuite(Cart.class);
 		suite.addTestSuite(Checkout.class); 
         return suite;

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Cart.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Cart.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Cart.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Cart.java Thu May 12 19:36:31 2005
@@ -48,7 +48,7 @@
 	  WebResponse resp = Util.navToItem("EST-4");	   
 
 	  // Add the item to the cart
-	  resp = resp.getFormWithID("addToCart").submit();
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonAddToCart")).click();
 
 	  // Make sure item is in the cart
 	  // Check the first two rows of the table
@@ -78,7 +78,7 @@
 	  resp = Util.navToItem("EST-4");	   
 
 	  // Add the item to the cart
-	  resp = resp.getFormWithID("addToCart").submit();
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonAddToCart")).click();
 
 	  // Make sure item is in the cart
 	  // Check the first two rows of the table
@@ -111,7 +111,7 @@
 	  resp = Util.navToItem("EST-4");	   
 
 	  // Add the item to the cart
-	  resp = resp.getFormWithID("addToCart").submit();
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonAddToCart")).click();
 
 	  // Make sure item is in the cart
 	  // Check the first two rows of the table

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Checkout.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Checkout.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Checkout.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Checkout.java Thu May 12 19:36:31 2005
@@ -38,7 +38,7 @@
 	  WebResponse resp = Util.navToItem("EST-4");	   
 
 	  // Add the item to the cart
-	  resp = resp.getFormWithID("addToCart").submit();
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonAddToCart")).click();
 
 	  // Make sure item is in the cart
 	  // Check the first two rows of the table
@@ -48,13 +48,13 @@
 	  assertEquals( "EST-4", table[1][0].trim());
 	  
   	  // proceed to checkout
-	  resp = resp.getLinkWith(Util.getBundle("view", "buttonProceedToCheckout") + " >>").click(); // "Proceed to Checkout"
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonProceedToCheckout")).click(); // "Proceed to Checkout"
 	  
 	  // Make sure it says Checkout Summary
 	  assertTrue(resp.getText().contains(Util.getBundle("view", "checkoutSummaryLabel"))); // "Checkout Summary"
 	  
 	  // Now click continue
-	  resp = resp.getLinkWith(Util.getBundle("view", "buttonContinue") + " >>").click(); // "Continue >>"
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonContinue")).click(); // "Continue >>"
 	  
 	  // Sign in
 	  WebForm form = resp.getForms()[1];
@@ -73,15 +73,15 @@
 	  
 	  // Make sure it took
 	  assertTrue(resp.getText().contains(Util.getBundle("view", "confirmMessage"))); // "Please confirm the information below and then press continue..."
-	  itemTable = resp.getTableStartingWith("New Order");
+	  itemTable = resp.getTableWithID("orderTable");
 	  itemTable.purgeEmptyCells();
 	  table = itemTable.asText();
-	  assertEquals( "American Express", table[2][1].trim());
-	  assertEquals( "1234", table[3][1].trim());
-	  assertEquals( "09-2000", table[4][1].trim());
+	  assertEquals( "American Express", table[1][1].trim());
+	  assertEquals( "1234", table[2][1].trim());
+	  assertEquals( "09-2000", table[3][1].trim());
 	  
 	  // Click Continue
-	  resp = resp.getLinkWith(Util.getBundle("view", "buttonContinue") + " >>").click(); // "Continue >>"
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonContinue")).click(); // "Continue >>"
 
 	  // Make sure it took
 	  assertTrue(resp.getText().contains(Util.getBundle("view", "orderSubmittedMessage"))); // "Thank you, your order has been submitted."
@@ -103,5 +103,22 @@
 	  String[][] table = itemTable.asText();
 	  assertEquals( "1", table[1][0].trim());
 	  assertEquals( "$18.50",  table[1][2].trim() );	  
+   }
+
+   public void testNewItemQuantity() throws Exception 
+   {
+	  /*
+	   * Make sure the new quantity is 9999
+	   */
+
+      // Start the conversation
+	  WebResponse resp = Util.navToItem("EST-4");
+	  
+	  // Check the first two rows of the table
+	  WebTable itemTable = resp.getTableStartingWith("EST-4");
+	  itemTable.purgeEmptyCells();
+	  String[][] table = itemTable.asText();
+	  assertEquals( "EST-4",  table[0][0].trim() );
+	  assertTrue( table[1][0].contains("9999 in Stock") );
    }
 }

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Navigation.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Navigation.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Navigation.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Navigation.java Thu May 12 19:36:31 2005
@@ -54,7 +54,7 @@
 	  WebResponse resp = Util.navToFrontPage();
 	  
 	  // Make sure the front page looks correct
-	  assertEquals(resp.getTitle().trim(), Util.getBundle("view", "indexTitle")); // "Beehive Petstore Demo"
+	  assertEquals(resp.getTitle().trim(), Util.getBundle("view", "indexTitle") + " - " + Util.getBundle("view", "welcomeLabel")); // "Beehive Petstore Demo"
 	  assertNotNull(resp.getLinkWith(Util.getBundle("view", "adminInit"))); // "Initialize the DB (recreates all tables and data)"
 	  assertNotNull(resp.getLinkWith(Util.getBundle("view", "adminStop"))); // "Stop Derby DB (stops the DB to allow redeploy)"
    }
@@ -65,6 +65,7 @@
 	  WebResponse resp = Util.navToStore();
 	  
 	  // Make sure main catalog page looks correct
+	  assertTrue( resp.getTitle().contains(Util.getBundle("view", "homeTitle")) );
 	  assertNotNull(resp.getLinkWith("Fish"));
 	  assertNotNull(resp.getLinkWith("Dogs"));
 	  assertNotNull(resp.getLinkWith("Reptiles"));
@@ -76,6 +77,10 @@
    {
       // Start the conversation
 	  WebResponse resp = Util.navToCategory("FISH");
+
+	  // Examine the page
+	  assertTrue( resp.getTitle().contains("- Fish") );
+	  assertNotNull(resp.getLinkWith(Util.getBundle("view", "mainMenuLabel"))); 
 	  
 	  // Check the first two rows of the table
 	  String[][] table = resp.getTableStartingWith(Util.getBundle("view", "productIdLabel")).asText(); // "Product ID"
@@ -91,6 +96,10 @@
    {
       // Start the conversation
 	  WebResponse resp = Util.navToProduct("FI-FW-01");
+
+	  // Examine the page
+	  assertTrue( resp.getTitle().contains("- Koi") );
+	  assertNotNull(resp.getLinkWith("FISH")); 
 	  
 	  // Check the first two rows of the table
 	  String[][] table = resp.getTableStartingWith(Util.getBundle("view", "itemIdLabel")).asText(); // "Item ID"
@@ -112,15 +121,18 @@
       // Start the conversation
 	  WebResponse resp = Util.navToItem("EST-4");
 	  
+	  // Examine the page
+	  assertTrue( resp.getTitle().contains("Spotted Koi") );
+	  assertTrue( resp.getText().contains("Fresh Water fish from Japan") );
+	  assertNotNull(resp.getLinkWith("Koi")); 
+
 	  // Check the first two rows of the table
 	  WebTable itemTable = resp.getTableStartingWith("EST-4");
 	  itemTable.purgeEmptyCells();
 	  String[][] table = itemTable.asText();
 	  assertEquals( "EST-4",  table[0][0].trim() );
-	  assertTrue( table[1][0].contains("Spotted") );
-	  assertEquals( "Fresh Water fish from Japan",  table[2][0] );
-	  assertTrue( table[3][0].contains("in Stock") );
-	  assertEquals( "$18.50",  table[4][0].trim() );
+	  assertTrue( table[1][0].contains("in Stock") );
+	  assertTrue( table[1][0].contains("$18.50") );
    }
 
 }

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/SignIn.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/SignIn.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/SignIn.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/SignIn.java Thu May 12 19:36:31 2005
@@ -49,4 +49,18 @@
 	  // Make sure we are signed out
 	  assertNotNull(resp.getLinkWith("Sign In"));		  
    }
+
+   public void testInvalidSignIn() throws Exception 
+   {
+	 /*
+	  * Test the error page by signing in as non_user
+	  */
+	  
+	  // Sign in as beehive
+	  WebResponse resp = Util.doSignIn("non_user", "non_user");
+	  
+	  // Make sure we have the error page
+	  assertTrue(resp.getText().contains(Util.getBundle("view", "loginErrorMessage"))); // "Sorry, your user name and password were not recognized."
+   }
+
 }

Added: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag?rev=169920&view=auto
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag (added)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag Thu May 12 19:36:31 2005
@@ -0,0 +1,31 @@
+<%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
+<%@ taglib uri="http://beehive.apache.org/netui/tags-databinding-1.0" prefix="netui-data"%>
+<%@ tag body-content="empty"%>
+
+<netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
+<netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.account" name="account"/>
+
+<table class="toolbar" cellpadding="1" cellspacing="0" width="100%" height="27">
+	<tr><td><table cellpadding="1" cellspacing="0">
+				<tr><td>
+						<netui:anchor action="rootSharedFlow.globalEditAccount" value="${bundle.view.myAccountLabel}" styleClass="toolbar" />
+					</td>
+					<td class="separator">|</td>
+					<td>
+						<netui:anchor action="rootSharedFlow.globalViewAddresses" value="${bundle.account.listAddressesLabel}" styleClass="toolbar" />
+					</td>
+					<td class="separator">|</td>
+					<td>
+<!--  TODO: fix this -->
+						<netui:anchor href="http://localhost:8080/petstoreWeb/account/edit/listOrders.do" value="${bundle.account.listOrdersLabel}" styleClass="toolbar" />
+					</td>
+					<td class="separator">|</td>
+					<td>
+						<netui:anchor action="rootSharedFlow.globalShop" value="${bundle.view.continueLabel}" styleClass="toolbar" />
+					</td>
+					<td class="separator">|</td>
+				</tr>
+			</table>
+		</td>
+	</tr>
+</table>
\ No newline at end of file

Propchange: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/accountNavHeader.tag
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/catalogNav.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/catalogNav.tag?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/catalogNav.tag (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/catalogNav.tag Thu May 12 19:36:31 2005
@@ -24,17 +24,13 @@
 <%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
 <%@ taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
 
-<p>
-<table class="tablegreen" align="left">
-    <tr class="rowyellow">
-      <td>
-        <netui:anchor action="${action}" styleClass="boldanchor">
-          <c:if test="${paramName != null && paramValue != null}">
-            <netui:parameter name="${paramName}" value="${paramValue}"/>
-          </c:if>
-          <netui:span styleClass="smalllabel" value="<< ${labelValue}"/>
-        </netui:anchor>
-      </td>
-    </tr>
-  </table>
-</p>
+<table class="tableborder" cellpadding="3" cellspacing="0" bgcolor="#eeeeee" width="200">
+	<tr><td>
+	    <netui:anchor action="${action}">
+		  <img src="${pageContext.request.contextPath}/images/arrow.gif" border=0 />  ${labelValue}
+	      <c:if test="${paramName != null && paramValue != null}">
+	        <netui:parameter name="${paramName}" value="${paramValue}"/>
+	      </c:if>
+	    </netui:anchor>
+	</td></tr>
+</table>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/categoryNavHeader.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/categoryNavHeader.tag?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/categoryNavHeader.tag (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/categoryNavHeader.tag Thu May 12 19:36:31 2005
@@ -17,46 +17,41 @@
 --%>
 <%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
 <%@ tag body-content="empty"%>
-<%@ attribute name="contextPath" required="true"%>
-
-<center>
 
 <%-- 
     todo: need to get the category list here and use a repeater
            to render each of the category links with a lookup
            to find the readable name for a category given an id
   --%>
-<netui:anchor action="rootSharedFlow.globalViewCategory" styleClass="boldanchor">
-    Fish
-    <netui:parameter name="catId" value="FISH"/>
-</netui:anchor>
-
-<netui:image border="0" src="${contextPath}/images/separator.gif"/>
-
-<netui:anchor action="rootSharedFlow.globalViewCategory" styleClass="boldanchor">
-    Dogs
-    <netui:parameter name="catId" value="DOGS"/>
-</netui:anchor>
-
-<netui:image border="0" src="${contextPath}/images/separator.gif"/>
-
-<netui:anchor action="rootSharedFlow.globalViewCategory" styleClass="boldanchor">
-    Reptiles
-    <netui:parameter name="catId" value="REPTILES"/>
-</netui:anchor>
-
-<netui:image border="0" src="${contextPath}/images/separator.gif"/>
-
-<netui:anchor action="rootSharedFlow.globalViewCategory" styleClass="boldanchor">
-    Cats
-    <netui:parameter name="catId" value="CATS"/>
-</netui:anchor>
-
-<netui:image border="0" src="${contextPath}/images/separator.gif"/>
-
-<netui:anchor action="rootSharedFlow.globalViewCategory" styleClass="boldanchor">
-    Birds
-    <netui:parameter name="catId" value="BIRDS"/>
-</netui:anchor>
-
-</center>
\ No newline at end of file
+<table class="toolbar" cellpadding="1" cellspacing="0" width="100%" height="27">
+	<tr><td><table cellpadding="1" cellspacing="0">
+				<tr><td><netui:anchor action="rootSharedFlow.globalViewCategory" value="Fish" styleClass="toolbar">
+						    <netui:parameter name="catId" value="FISH"/>
+						</netui:anchor>
+					</td>
+					<td class="separator">|</td>
+					<td><netui:anchor action="rootSharedFlow.globalViewCategory" value="Dogs" styleClass="toolbar">
+						    <netui:parameter name="catId" value="DOGS"/>
+						</netui:anchor>
+					</td>
+					<td class="separator">|</td>
+					<td><netui:anchor action="rootSharedFlow.globalViewCategory" value="Reptiles" styleClass="toolbar">
+						    <netui:parameter name="catId" value="REPTILES"/>
+						</netui:anchor>
+					</td>
+					<td class="separator">|</td>
+					<td><netui:anchor action="rootSharedFlow.globalViewCategory" value="Cats" styleClass="toolbar">
+						    <netui:parameter name="catId" value="CATS"/>
+						</netui:anchor>
+					</td>
+					<td class="separator">|</td>
+					<td><netui:anchor action="rootSharedFlow.globalViewCategory" value="Birds" styleClass="toolbar">
+						    <netui:parameter name="catId" value="BIRDS"/>
+						</netui:anchor>
+					</td>
+					<td class="separator">|</td>
+				</tr>
+			</table>
+		</td>
+	</tr>
+</table>
\ No newline at end of file

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/headerMenu.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/headerMenu.tag?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/headerMenu.tag (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/headerMenu.tag Thu May 12 19:36:31 2005
@@ -17,55 +17,42 @@
 --%>
 <%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
 <%@ taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
+<%@ taglib uri="http://beehive.apache.org/netui/tags-databinding-1.0" prefix="netui-data"%>
 
 <%@ tag body-content="empty" %>
 <%@ attribute name="contextPath" required="true" %>
 
-<%--
-    todo: switch the hard-coded strings below to strings in a resource bundle
-          seems that there's a bug in the ${bundle} implicit object that
-          prevents this from working correctly...
-    - ekoneil
-  --%>
+<netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
+
 <table background="${contextPath}/images/bkg-topbar.gif" border="0" cellspacing="0" cellpadding="5" width="100%">
   <tr>
     <td align="left" width="60%">
       <%-- shop --%>
       <netui:imageAnchor action="rootSharedFlow.globalShop" border="0" src="${contextPath}/images/logo-topbar.gif" height="60" width="287"/>
     </td>
-    <td valign="top" align="right" nowrap="nowrap">
-      <br clear="all"/>
+    <td valign="middle" align="right" nowrap="nowrap">
       <%-- view cart --%>
-      <netui:imageAnchor action="rootSharedFlow.globalViewCart" border="0" src="${contextPath}/images/cart.gif"/>
-      <netui:image border="0" src="${contextPath}/images/separator.gif"/>
-      <c:choose>
-        <c:when test="${sharedFlow.rootSharedFlow.account == null}">
-          <%-- sharedFlow.signon --%>
-          <netui:anchor styleClass="boldanchor" action="rootSharedFlow.signon">
-              Sign In
-          </netui:anchor>
-        </c:when>
-        <c:otherwise>
-          <%-- sharedFlow.signoff --%>
-          <netui:anchor styleClass="boldanchor" action="rootSharedFlow.signoff">
-              Sign Out
-          </netui:anchor>
-          <netui:image border="0" src="${contextPath}/images/separator.gif"/>
-          <netui:anchor styleClass="boldanchor" action="rootSharedFlow.globalEditAccount">
-              My Account
-          </netui:anchor>
-        </c:otherwise>
-      </c:choose>
-      <netui:image border="0" src="${contextPath}/images/separator.gif"/>
-      <netui:imageAnchor action="rootSharedFlow.globalShowHelp" border="0" src="${contextPath}/images/help.gif"/>
-    </td>
-    <td valign="top" align="left" border="0">
-      <br clear="all"/>
       <netui:form action="rootSharedFlow.search">
-        <netui:textBox dataSource="actionForm.keyword" size="14"/>
-          <netui:anchor styleClass="boldanchor" formSubmit="true">
-              Search
-          </netui:anchor>
+	      <netui:imageAnchor action="rootSharedFlow.globalViewCart" border="0" src="${contextPath}/images/cart.gif"/>
+	      <netui:image border="0" src="${contextPath}/images/separator.gif"/>
+	      <c:choose>
+	        <c:when test="${sharedFlow.rootSharedFlow.account == null}">
+	          <%-- sharedFlow.signon --%>
+	          <netui:anchor value="${bundle.view.signinLabel}" styleClass="boldanchor" action="rootSharedFlow.signon" />
+	        </c:when>
+	        <c:otherwise>
+	          <%-- sharedFlow.signoff --%>
+	          <netui:anchor value="${bundle.view.signoffLabel}" styleClass="boldanchor" action="rootSharedFlow.signoff" />
+	          <netui:image border="0" src="${contextPath}/images/separator.gif"/>
+	          <netui:anchor value="${bundle.view.myAccountLabel}" styleClass="boldanchor" action="rootSharedFlow.globalEditAccount" />
+	        </c:otherwise>
+	      </c:choose>
+	      <netui:image border="0" src="${contextPath}/images/separator.gif"/>
+		  <%-- help --%>
+		  <netui:imageAnchor action="rootSharedFlow.globalShowHelp" border="0" src="${contextPath}/images/help.gif"/>
+		  <%-- search --%>
+	      <netui:textBox dataSource="actionForm.keyword" size="14"/>
+	      <netui:anchor value="${bundle.view.searchLabel}" styleClass="boldanchor" formSubmit="true" />
       </netui:form>
     <td>
   </tr>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/orderSummary.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/orderSummary.tag?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/orderSummary.tag (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/orderSummary.tag Thu May 12 19:36:31 2005
@@ -21,180 +21,147 @@
 
 <%@ tag body-content="empty" %>
 
-<%--
-  This tag also implicitly expects that the "actionForm" and "bundle"
-  objects are passed in explicitly.
-
-  Either NetUI or JSP needs to have an <assert> tag.  <g>
---%>
 <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
 
-<table class="tablegreen" width="60%" align="center">
-  <tr class="rowyellow">
-    <td align="center" colspan="2">
-	  <c:choose>
-	      <c:when test="${pageInput.order.orderId != -1}">
-    	      <netui:span styleClass="boldlabel" value="${bundle.view.orderNumberLabel} ${pageInput.order.orderId}"/>
-		      <br/>
-		      <netui:span styleClass="boldlabel" value="${pageInput.order.orderDate}">
-        	  <netui:formatDate pattern="${bundle.view.orderDateFormat}"/>
-    	      </netui:span>
-          </c:when>
-          <c:otherwise>
-		      <netui:span styleClass="boldlabel" value="${bundle.view.newOrderLabel}" />
-          </c:otherwise>
-      </c:choose>
-    </td>
-  </tr>
-  <tr class="rowyellow">
-    <td colspan="2">
+<table cellpadding="3" cellspacing="1" id="orderTable">
+  <c:if test="${pageInput.order.orderId != -1}">
+	  <tr>
+	    <td align="center" colspan="3">
+	      <netui:span styleClass="boldlabel" value="${bundle.view.orderNumberLabel} ${pageInput.order.orderId}"/>
+	      <br/>
+	      <netui:span styleClass="boldlabel" value="${pageInput.order.orderDate}">
+	    	  <netui:formatDate pattern="${bundle.view.orderDateFormat}"/>
+	      </netui:span>
+	    </td>
+	  </tr>
+  </c:if>
+  <tr>
+    <td colspan="3">
       <netui:span styleClass="boldlabel" value="${bundle.view.paymentDetailsLabel}"/>
     </td>
   </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.cardTypeLabel}:</td>
-    <td class="celldata">
+  <tr>
+    <td class="cellgrey">${bundle.view.cardTypeLabel}:</td>
+    <td class="cellltgrey" colspan="2">
       <netui:span value="${pageInput.order.cardType}"/>
     </td>
   </tr>
-  <tr class="rowyellow">
-      <td class="celldata">${bundle.view.cardNumberLabel}:</td>
-      <td class="celldata"><netui:span value="${pageInput.order.creditCard}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.expirationDateLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.order.exprDate}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td colspan="2">
-      <netui:span styleClass="boldlabel" value="${bundle.view.billingAddressLabel}"/>
-    </td>
+  <tr>
+      <td class="cellgrey">${bundle.view.cardNumberLabel}:</td>
+      <td class="cellltgrey" colspan="2"><netui:span value="${pageInput.order.creditCard}"/></td>
   </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.nameLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.name}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.address1Label}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.addr1}"/></td>
-  </tr>
-  <c:if test="${pageInput.billingAddress.addr2} != ''">
-	  <tr class="rowyellow">
-	    <td class="celldata">${bundle.view.address2Label}:</td>
-	    <td class="celldata"><netui:span value="${pageInput.billingAddress.addr2}"/></td>
-	  </tr>
-  </c:if>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.cityLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.city}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.stateLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.state}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.zipLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.zip}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.countryLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.billingAddress.country}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td colspan="2">
-      <netui:span styleClass="boldlabel" value="${bundle.view.shippingAddressLabel}"/>
-    </td>
+  <tr>
+    <td class="cellgrey">${bundle.view.expirationDateLabel}:</td>
+    <td class="cellltgrey" colspan="2"><netui:span value="${pageInput.order.exprDate}"/></td>
   </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.nameLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.name}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.address1Label}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.addr1}"/></td>
-  </tr>
-  <c:if test="${pageInput.shippingAddress.addr2} != ''">
-	  <tr class="rowyellow">
-	    <td class="celldata">${bundle.view.address2Label}:</td>
-	    <td class="celldata"><netui:span value="${pageInput.shippingAddress.addr2}"/></td>
-	  </tr>
-  </c:if>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.cityLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.city}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.stateLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.state}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.zipLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.zip}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td class="celldata">${bundle.view.countryLabel}:</td>
-    <td class="celldata"><netui:span value="${pageInput.shippingAddress.country}"/></td>
-  </tr>
-  <tr class="rowyellow">
-    <td colspan="2">
-      <netui:span styleClass="greenboldlabel" value="${bundle.view.orderStatus} ${pageInput.order.status}"/>
+  <tr>
+    <td>
+      <br/>
+      <netui:span styleClass="boldlabel" value="${bundle.view.addresses}"/>
+    </td>
+    <td>
+      <br/>
+      <netui:span styleClass="boldlabel" value="${bundle.view.billingLabel}"/>
+    </td>
+    <td>
+      <br/>
+      <netui:span styleClass="boldlabel" value="${bundle.view.shippingLabel}"/>
     </td>
   </tr>
   <tr>
-  <td colspan="2">
-  <table class="tablegreen" align="center" width="100%">
-    <tr class="rowgrey">
-      <td class="celldata"><b>${bundle.view.itemIdLabel}</b></td>
-      <td class="celldata"><b>${bundle.view.descriptionLabel}</b></td>
-      <td class="celldata"><b>${bundle.view.quantityLabel}</b></td>
-      <td class="celldata"><b>${bundle.view.unitPriceLabel}</b></td>
-      <td class="celldata"><b>${bundle.view.totalCostLabel}</b></td>
-    </tr>
-    <netui-data:repeater dataSource="pageInput.lineItems">
-      <tr class="rowyellow">
-        <td class="celldata"><b>
-        <c:choose>
-          <c:when test="${pageScope.checkout == false}">
-            <netui:anchor action="viewItem.do">
-              <netui:parameter name="itemId" value="${container.item.item.itemId}"/>
-              <netui:span value="${container.item.item.itemId}"/>
-            </netui:anchor>
-          </c:when>
-          <c:otherwise>
-            <netui:span value="${container.item.item.itemId}"/>
-          </c:otherwise>
-        </c:choose>
-        </b>
-        </td>
-        <td class="celldata">
-          <netui:span value="${container.item.item.attr1}"/>
-          <netui:span value="${container.item.item.productName}"/>
-        </td>
-        <td align="center">
-          <netui:span value="${container.item.quantity}"/>
-        </td>
-        <td align="right">
-          <netui:span value="${container.item.item.listPrice}">
-            <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
-          </netui:span>
-        </td>
-        <td align="right">
-          <netui:span value="${container.item.total}">
-            <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
-          </netui:span>
-        </td>
-      </tr>
-    </netui-data:repeater>
-    <tr class="rowyellow">
-      <td colspan="6" align="right">
-        <b>${bundle.view.totalCostLabel}:
-        <netui:span value="${pageInput.order.totalPrice}">
-          <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
-        </netui:span>
-        </b><br/>
-      </td>
-    </tr>
-  </table>
+    <td class="cellgrey">${bundle.view.nameLabel}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.name}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.name}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.address1Label}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.addr1}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.addr1}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.address2Label}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.addr2}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.addr2}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.cityLabel}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.city}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.city}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.stateLabel}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.state}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.state}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.zipLabel}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.zip}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.zip}"/></td>
+  </tr>
+  <tr>
+    <td class="cellgrey">${bundle.view.countryLabel}:</td>
+    <td class="cellltgrey"><netui:span value="${pageInput.billingAddress.country}"/></td>
+    <td class="cellltgrey"><netui:span value="${pageInput.shippingAddress.country}"/></td>
+  </tr>
+  <tr>
+  <tr>
+    <td colspan="3">
+      <br/>
+      <netui:span styleClass="boldlabel" value="${bundle.view.orderDetails}"/>
+    
+	  <table class="tableborder" width="100%" cellpadding="3" cellspacing="1">
+	    <tr class="rowgrey">
+	      <td><b>${bundle.view.itemIdLabel}</b></td>
+	      <td><b>${bundle.view.descriptionLabel}</b></td>
+	      <td><b>${bundle.view.quantityLabel}</b></td>
+	      <td><b>${bundle.view.unitPriceLabel}</b></td>
+	      <td><b>${bundle.view.totalCostLabel}</b></td>
+	    </tr>
+	    <netui-data:repeater dataSource="pageInput.lineItems">
+	      <tr>
+	        <td class="cellltgrey"><b>
+	        <c:choose>
+	          <c:when test="${pageScope.checkout == false}">
+	            <netui:anchor action="viewItem.do">
+	              <netui:parameter name="itemId" value="${container.item.item.itemId}"/>
+	              <netui:span value="${container.item.item.itemId}"/>
+	            </netui:anchor>
+	          </c:when>
+	          <c:otherwise>
+	            <netui:span value="${container.item.item.itemId}"/>
+	          </c:otherwise>
+	        </c:choose>
+	        </b>
+	        </td>
+	        <td class="cellltgrey">
+	          <netui:span value="${container.item.item.attr1}"/>
+	          <netui:span value="${container.item.item.productName}"/>
+	        </td>
+	        <td class="cellltgrey" align="center">
+	          <netui:span value="${container.item.quantity}"/>
+	        </td>
+	        <td align="right" class="cellltgrey">
+	          <netui:span value="${container.item.item.listPrice}">
+	            <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
+	          </netui:span>
+	        </td>
+	        <td align="right" class="cellltgrey">
+	          <netui:span value="${container.item.total}">
+	            <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
+	          </netui:span>
+	        </td>
+	      </tr>
+	    </netui-data:repeater>
+	    <tr>
+	      <td colspan="6" align="right">
+	        <b>${bundle.view.totalCostLabel}:
+	        <netui:span value="${pageInput.order.totalPrice}">
+	          <netui:formatNumber pattern="${bundle.view.priceFormat}"/>
+	        </netui:span>
+	        </b><br/>
+	      </td>
+	    </tr>
+	  </table>
   </td>
   </tr>
 </table>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/productFavorites.tag
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/productFavorites.tag?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/productFavorites.tag (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/WEB-INF/tags/beehive/petstore/productFavorites.tag Thu May 12 19:36:31 2005
@@ -21,10 +21,7 @@
 <%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
 
 <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
-<p>
-  &nbsp;
-</p>
-<table class="tablegreen">
+<table class="tableborder" cellpadding="0" cellspacing="1" width="200">
     <tr class="rowgrey">
         <td>
         <netui:span styleClass="boldlabel" value="${bundle.view.petFavoritesLabel}"/>
@@ -32,8 +29,8 @@
         <i>${bundle.view.shopForFavoritesLabel}.</i>
         </td>
     </tr>
-    <tr class="rowyellow">
-        <td>
+    <tr>
+        <td  class="cellltgrey">
         <netui-data:repeater dataSource="sharedFlow.rootSharedFlow.myList">
             <netui:anchor action="viewProduct">
                 <netui:parameter name="productId" value="${container.item.productId}"/>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/createUpdate.jsp
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/createUpdate.jsp?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/createUpdate.jsp (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/createUpdate.jsp Thu May 12 19:36:31 2005
@@ -25,88 +25,88 @@
 <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
 
 <netui-template:template templatePage="/site/template.jsp">
-    <netui-template:section name="leftnav">
-        &nbsp; 
-    </netui-template:section>
+
     <netui-template:section name="body">
     <netui:errors/>
+	<style>
+		#leftnav {display: none;}
+	</style>
     <netui:form action="updateAddress">
 	    <netui:hidden dataSource="actionForm.userId" />
 	    <netui:hidden dataSource="actionForm.addressId" />
     <center>
-        <table cellpadding=10 cellspacing=0 align=center border=1 bgcolor=#dddddd>
+	        <table cellpadding="0" cellspacing="0">
             <tr>
                 <td>
-                <netui:span styleClass="boldlabel" value="${bundle.view.address}"/>
-                <table bgcolor="#008800" border=0 cellpadding=3 cellspacing=1>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.nameLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.name"/>
-                        <br/>
-                        <netui:error key="name"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.address1Label}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.addr1" />
-                        <br/>
-                        <netui:error key="address1"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.address2Label}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.addr2" />
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.cityLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.city" />
-                        <br/>
-                        <netui:error key="city"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.stateLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.state" />
-                        <br/>
-                        <netui:error key="state"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.zipLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.zip" />
-                        <br/>
-                        <netui:error key="zip"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.countryLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.country" />
-                        <br/>
-                        <netui:error key="country"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.view.phoneLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.phone" />
-                        <br/>
-                        <netui:error key="phone"/>
+		        <c:choose>
+			        <c:when test="${actionForm.addressId == -1}">
+		                <netui:span styleClass="boldlabel" value="${bundle.view.newAddress}"/>
+			        </c:when>
+			        <c:otherwise>
+		                <netui:span styleClass="boldlabel" value="${bundle.view.editAddress}"/>
+			        </c:otherwise>
+			    </c:choose>
+		        <table class="tableborder" cellpadding="0" cellspacing="1" width="400">
+                    <tr>
+                        <td class="cellgrey">${bundle.view.nameLabel}:</td>
+                        <td class="cellltgrey">
+                        	<netui:textBox dataSource="actionForm.name"/>
+	                        <br/>
+	                        <netui:error key="name"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.address1Label}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.addr1" />
+	                        <br/>
+	                        <netui:error key="address1"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.address2Label}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.addr2" />
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.cityLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.city" />
+	                        <br/>
+	                        <netui:error key="city"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.stateLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.state" />
+	                        <br/>
+	                        <netui:error key="state"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.zipLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.zip" />
+	                        <br/>
+	                        <netui:error key="zip"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.countryLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.country" />
+	                        <br/>
+	                        <netui:error key="country"/>
+                        </td>
+                    </tr>
+                    <tr>
+                        <td class="cellgrey">${bundle.view.phoneLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.phone" />
+	                        <br/>
+	                        <netui:error key="phone"/>
                         </td>
                     </tr>
                 </td>
@@ -122,8 +122,10 @@
 						<netui:button value="${bundle.view.buttonUpdate}" />
 			        </c:otherwise>
 			    </c:choose>
-		        &nbsp;&nbsp;
-				<netui:button value="${bundle.view.buttonCancel}" onClick="javascript:window.location.href='${pageContext.request.contextPath}/account/addresses/begin.do';" />
+		        <br/><br/>
+				<netui:anchor action="begin">
+					<img src="${pageContext.request.contextPath}/images/arrow.gif" border=0 /> ${bundle.view.buttonCancel}
+				</netui:anchor>
 		        </CENTER>
 				</td>
 			</tr>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/listAddresses.jsp
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/listAddresses.jsp?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/listAddresses.jsp (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/account/addresses/listAddresses.jsp Thu May 12 19:36:31 2005
@@ -20,26 +20,33 @@
 <%@ taglib uri="http://beehive.apache.org/netui/tags-html-1.0" prefix="netui"%>
 <%@ taglib uri="http://beehive.apache.org/netui/tags-template-1.0" prefix="netui-template"%>
 <%@ taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
+<%@ taglib prefix="beehive-petstore" tagdir="/WEB-INF/tags/beehive/petstore" %>
 
 <netui-data:declarePageInput name="addresses" type="org.apache.beehive.samples.petstore.model.address[]" required="true"/>
+<netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
 
 <netui-template:template templatePage="/site/template.jsp">
-    <netui-template:section name="leftnav"> &nbsp; </netui-template:section>
+
+	<netui-template:setAttribute name="title" value="${bundle.view.addresses}" />
+
+    <netui-template:section name="topMenu"> 
+		<beehive-petstore:accountNavHeader />
+	</netui-template:section>
 
     <netui-template:section name="body">
-    <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
+	<!-- Turn off the leftnav -->
+	<style> #leftnav {display: none;} </style>
+	
     <center> 
-    <table cellpadding="10" cellspacing="0" align="center" bgcolor="#dddddd">
+        <table cellpadding="3" cellspacing="0">
         <tr>
             <td>
 			    <netui:span styleClass="boldlabel" value="${bundle.view.addresses}"/>
 			    <netui-data:repeater dataSource="pageInput.addresses" defaultText="<br/><br/>No addresses found<br/><br/>">
-			        <netui-data:repeaterHeader>
-			            <table class="tablegreen" id="addresses">
-			        </netui-data:repeaterHeader>
 			        <netui-data:repeaterItem>
-			            <tr valign="top" class="rowyellow">
-			                <td class="celldata" id="address_${container.item.name}">
+			        <table class="tableborder" cellpadding="3" cellspacing="0" width="100%" id="address_${container.item.name}">
+			            <tr>
+			                <td class="cellltgrey">
 			                    <netui:span value="${container.item.name}" /><br/>
 			                    <netui:span value="${container.item.addr1}" /><br/>
 			                    <netui:span value="${container.item.addr2}" />
@@ -50,7 +57,8 @@
 			                    <netui:span value="${container.item.state}" />
 			                    <netui:span value="${container.item.zip}" /><br/>
 			                    <netui:span value="${container.item.country}" /><br/>
-			                    <netui:span value="${container.item.phone}" /><br/>
+			                    <netui:span value="${container.item.phone}" />
+			                    <hr/>
 			                    <center>
 								<netui:anchor action="createUpdateAddress" value="${bundle.view.buttonEdit}">
 									<netui:parameter name="addressId" value="${container.item.addressId}"/>
@@ -62,24 +70,19 @@
 					            </center>
 			                </td>
 			            </tr>
+			        </table>
 			        </netui-data:repeaterItem>
-			        <netui-data:repeaterFooter>
-			            </table>
-			        </netui-data:repeaterFooter>
 			    </netui-data:repeater>
 			    <br/>
 			    <center>
-			    <netui:form action="createUpdateAddress" tagId="addAddress">
-					<netui:button value="${bundle.view.buttonAddAddress}" />&nbsp;&nbsp;
-				</netui:form> 
 		        <c:if test="${sharedFlow.rootSharedFlow.account.status == 'checking_out'}">
 				    <netui:anchor action="rootSharedFlow.globalCheckOut.do">
-				    	<b>${bundle.view.checkoutReturn}</b>
-				    </netui:anchor><br/>
+				    	<img src="${pageContext.request.contextPath}/images/arrow_forward.gif" border=0 /> ${bundle.view.checkoutReturn}
+				    </netui:anchor>&nbsp;&nbsp;&nbsp;
 				</c:if>
-			    <netui:anchor action="rootSharedFlow.globalEditAccount.do">
-			    	<b>${bundle.view.myAccountLabel}</b>
-			    </netui:anchor>
+				<netui:anchor styleClass="navigation" action="createUpdateAddress">
+					${bundle.view.buttonAddAddress} <img src="${pageContext.request.contextPath}/images/arrow_forward.gif" border=0 />
+				</netui:anchor>
 			    </center>
 			</td>
 		</tr>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/account/create/create.jsp
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/account/create/create.jsp?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/account/create/create.jsp (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/account/create/create.jsp Thu May 12 19:36:31 2005
@@ -26,104 +26,107 @@
 <netui-data:declarePageInput name="languages" type="java.lang.String[]"/>
 <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
 
+
 <netui-template:template templatePage="/site/template.jsp">
-    <netui-template:section name="leftnav">
-        &nbsp; 
-    </netui-template:section>
+  
+	<netui-template:setAttribute name="title" value="${bundle.view.createAccountLabel}" />
+
     <netui-template:section name="body">
+
+	<!-- Turn off the leftnav -->
+	<style> #leftnav {display: none;} </style>
+
     <netui:errors/>
     <netui:form action="createAccount">
     <center>
-        <table cellpadding=10 cellspacing=0 align=center border=1 bgcolor=#dddddd>
+        <table cellpadding=5 cellspacing=0 width="460">
             <tr>
                 <td>
                 <netui:span styleClass="boldlabel" value="${bundle.default.userInformation}"/>
-                <table bgcolor="#008800" border=0 cellpadding=3 cellspacing=1>
-                    <tr class="rowyellow">
-                        <td>${bundle.default.userIdLabel}:
-                        </td>
-                        <td>
-                        <c:if test="${pageFlow.usernameTaken == true}">
-                        <netui:span styleClass="error" value="${bundle.default.usernameTaken}"/>
-                        <br/>
-                        </c:if>
-                        <netui:textBox dataSource="actionForm.userId"/>
-                        <br/>
-                        <netui:error key="userId"/>
+                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+                    <tr>
+                        <td class="cellgrey">${bundle.default.userIdLabel}:</td>
+                        <td class="cellltgrey">
+	                        <c:if test="${pageFlow.usernameTaken == true}">
+		                        <netui:span styleClass="error" value="${bundle.default.usernameTaken}"/>
+		                        <br/>
+	                        </c:if>
+	                        <netui:textBox dataSource="actionForm.userId"/>
+	                        <br/>
+	                        <netui:error key="userId"/>
                         </td>
                     </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.default.passwordLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox password="true" dataSource="actionForm.password"/>
-                        <br/>
-                        <netui:error key="password"/>
+                    <tr>
+                        <td class="cellgrey">${bundle.default.passwordLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox password="true" dataSource="actionForm.password"/>
+	                        <br/>
+	                        <netui:error key="password"/>
                         </td>
                     </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.default.repeatPasswordLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.repeatedPassword" password="true"/>
-                        <br/>
-                        <netui:error key="password"/>
+                    <tr>
+                        <td class="cellgrey">${bundle.default.repeatPasswordLabel}:</td>
+                        <td class="cellltgrey">
+	                        <netui:textBox dataSource="actionForm.repeatedPassword" password="true"/>
+	                        <br/>
+	                        <netui:error key="password"/>
                         </td>
                     </tr>
                 </table>
+                <br/>
                 <netui:span styleClass="boldlabel" value="${bundle.default.accountInformation}"/>
-				<table class="tablegreen">
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.firstName}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.firstName"/>
-				        <br/>
-				        <netui:error key="firstName"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.lastName}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.lastName"/>
-				        <br/>
-				        <netui:error key="lastName"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.email}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.email" size="40"/>
-				        <br/>
-				        <netui:error key="email"/>
+                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.firstName}:"/></td>
+				        <td class="cellltgrey">
+					        <netui:textBox dataSource="actionForm.firstName"/>
+					        <br/>
+					        <netui:error key="firstName"/>
+				        </td>
+				    </tr>
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.lastName}:"/></td>
+				        <td class="cellltgrey">
+					        <netui:textBox dataSource="actionForm.lastName"/>
+					        <br/>
+					        <netui:error key="lastName"/>
+				        </td>
+				    </tr>
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.email}:"/></td>
+				        <td class="cellltgrey">
+					        <netui:textBox dataSource="actionForm.email" size="35"/>
+					        <br/>
+					        <netui:error key="email"/>
 				        </td>
 				    </tr>
 				</table>
 				
+				<br/>
 				<netui:span styleClass="boldlabel" value="${bundle.default.profileInformation}"/>
-				
-				<table class="tablegreen">
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.languagePreference}:"/></td>
-				        <td class="celldata">
-				        <netui:select dataSource="actionForm.langPref" optionsDataSource="${pageInput.languages}"/>
+                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.languagePreference}:"/></td>
+				        <td class="cellltgrey">
+					        <netui:select dataSource="actionForm.langPref" optionsDataSource="${pageInput.languages}"/>
 				        </td>
 				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.favoriteCategory}:"/></td>
-				        <td class="celldata">
-				        <netui:select dataSource="actionForm.favCategory" optionsDataSource="${pageInput.categoryNames}"/>
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.favoriteCategory}:"/></td>
+				        <td class="cellltgrey">
+					        <netui:select dataSource="actionForm.favCategory" optionsDataSource="${pageInput.categoryNames}"/>
 				        </td>
 				    </tr>
-				    <tr class="rowyellow">
-				        <td colspan=2>
-				        <netui:checkBox dataSource="actionForm.myListOpt"/>
-				        <netui:span value="${bundle.default.enableMyList}"/>
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.enableMyList}"/></td>
+				        <td class="cellltgrey">
+					        <netui:checkBox dataSource="actionForm.myListOpt"/>
 				        </td>
 				    </tr>
-				    <tr class="rowyellow">
-				        <td colspan=2>
-				        <netui:checkBox dataSource="actionForm.bannerOpt"/>
-				        <netui:span value="${bundle.default.enableMyBanner}"/>
+				    <tr>
+				        <td class="cellgrey"><netui:span value="${bundle.default.enableMyBanner}"/></td>
+				        <td class="cellltgrey">
+					        <netui:checkBox dataSource="actionForm.bannerOpt"/>
 				        </td>
 				    </tr>
 				</table>

Modified: incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/edit.jsp
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/edit.jsp?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================
--- incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/edit.jsp (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/web/account/edit/edit.jsp Thu May 12 19:36:31 2005
@@ -26,107 +26,112 @@
 <netui-data:declareBundle bundlePath="org.apache.beehive.samples.petstore.resources.view" name="view"/>
 
 <netui-template:template templatePage="/site/template.jsp">
-    <netui-template:section name="leftnav"> &nbsp; </netui-template:section>
 
-    <netui-template:section name="body"> <center>
-    <netui:form action="updateAccount">
-        <table cellpadding="10" cellspacing="0" align="center" bgcolor="#dddddd">
-            <tr>
-                <td>
-                <netui:span styleClass="boldlabel" value="${bundle.default.userInformation}"/>
-                <table class="tablegreen">
-                    <tr class="rowyellow">
-                        <td>${bundle.default.userIdLabel}:
-                        </td>
-                        <td><netui:span value="${actionForm.userId}"/></td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.default.passwordLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.newPassword" password="true"/>
-                        </td>
-                    </tr>
-                    <tr class="rowyellow">
-                        <td>${bundle.default.repeatPasswordLabel}:
-                        </td>
-                        <td>
-                        <netui:textBox dataSource="actionForm.repeatedPassword" password="true"/>
-                        </td>
-                    </tr>
-                </table>
-                <netui:span styleClass="boldlabel" value="${bundle.default.accountInformation}"/>
-				<table class="tablegreen">
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.firstName}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.firstName"/>
-				        <br/>
-				        <netui:error key="firstName"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.lastName}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.lastName"/>
-				        <br/>
-				        <netui:error key="lastName"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.email}:"/></td>
-				        <td class="celldata">
-				        <netui:textBox dataSource="actionForm.email" size="40"/>
-				        <br/>
-				        <netui:error key="email"/>
-				        </td>
-				    </tr>
-				</table>
-				
-				<netui:span styleClass="boldlabel" value="${bundle.default.profileInformation}"/>
-				
-				<table class="tablegreen">
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.languagePreference}:"/></td>
-				        <td class="celldata">
-				        <netui:select dataSource="actionForm.langPref" optionsDataSource="${pageInput.languages}"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td class="celldata"><netui:span value="${bundle.default.favoriteCategory}:"/></td>
-				        <td class="celldata">
-				        <netui:select dataSource="actionForm.favCategory" optionsDataSource="${pageInput.categoryNames}"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td colspan=2>
-				        <netui:checkBox dataSource="actionForm.myListOpt"/>
-				        <netui:span value="${bundle.default.enableMyList}"/>
-				        </td>
-				    </tr>
-				    <tr class="rowyellow">
-				        <td colspan=2>
-				        <netui:checkBox dataSource="actionForm.bannerOpt"/>
-				        <netui:span value="${bundle.default.enableMyBanner}"/>
-				        </td>
-				    </tr>
-				</table>
-				
-                </td>
-            </tr>
-            <tr>
-                <td>
-                <center>
-		        <netui:button value="${bundle.view.buttonSubmit}" />
-                <br/>
-                <br/>
-			    <netui:anchor action="rootSharedFlow.globalViewAddresses.do">
-			    	<b>${bundle.default.listAddressesLabel}</b>
-			    </netui:anchor><br/>
-                <netui:anchor action="listOrders">
-                    <b>${bundle.default.listOrdersLabel}</b>
-                </netui:anchor>
-                </center>
-                </netui:form>
-    </td> </tr> </table> </netui-template:section>
+	<netui-template:setAttribute name="title" value="${bundle.view.myAccountLabel}" />
+
+    <netui-template:section name="topMenu"> 
+		<beehive-petstore:accountNavHeader />
+	</netui-template:section>
+
+    <netui-template:section name="body"> 
+
+		<!-- Turn off the leftnav -->
+		<style> #leftnav {display: none;} </style>
+	    
+	    <center>
+	    <netui:form action="updateAccount">
+	        <table cellpadding=5 cellspacing=0 width="460">
+	            <tr>
+	                <td>
+	                <netui:span styleClass="boldlabel" value="${bundle.default.userInformation}"/>
+	                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+	                    <tr>
+	                        <td class="cellgrey">${bundle.default.userIdLabel}:</td>
+	                        <td class="cellltgrey"><netui:span value="${actionForm.userId}"/></td>
+	                    </tr>
+	                    <tr>
+	                        <td class="cellgrey">${bundle.default.passwordLabel}:</td>
+	                        <td class="cellltgrey">
+		                        <netui:textBox dataSource="actionForm.newPassword" password="true"/>
+	                        </td>
+	                    </tr>
+	                    <tr>
+	                        <td class="cellgrey">${bundle.default.repeatPasswordLabel}:</td>
+	                        <td class="cellltgrey">
+		                        <netui:textBox dataSource="actionForm.repeatedPassword" password="true"/>
+	                        </td>
+	                    </tr>
+	                </table>
+	
+	                <br/>
+	                <netui:span styleClass="boldlabel" value="${bundle.default.accountInformation}"/>
+	                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.firstName}:"/></td>
+					        <td class="cellltgrey">
+						        <netui:textBox dataSource="actionForm.firstName"/>
+						        <br/>
+						        <netui:error key="firstName"/>
+					        </td>
+					    </tr>
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.lastName}:"/></td>
+					        <td class="cellltgrey">
+						        <netui:textBox dataSource="actionForm.lastName"/>
+						        <br/>
+						        <netui:error key="lastName"/>
+					        </td>
+					    </tr>
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.email}:"/></td>
+					        <td class="cellltgrey">
+						        <netui:textBox dataSource="actionForm.email" size="35"/>
+						        <br/>
+						        <netui:error key="email"/>
+					        </td>
+					    </tr>
+					</table>
+					
+					<br/>				
+					<netui:span styleClass="boldlabel" value="${bundle.default.profileInformation}"/>
+	                <table class="tableborder" width="100%" cellpadding="0" cellspacing="1">
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.languagePreference}:"/></td>
+					        <td class="cellltgrey">
+					        	<netui:select dataSource="actionForm.langPref" optionsDataSource="${pageInput.languages}"/>
+					        </td>
+					    </tr>
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.favoriteCategory}:"/></td>
+					        <td class="cellltgrey">
+						        <netui:select dataSource="actionForm.favCategory" optionsDataSource="${pageInput.categoryNames}"/>
+					        </td>
+					    </tr>
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.enableMyList}"/></td>
+					        <td class="cellltgrey">
+						        <netui:checkBox dataSource="actionForm.myListOpt"/>
+					        </td>
+					    </tr>
+					    <tr>
+					        <td class="cellgrey"><netui:span value="${bundle.default.enableMyBanner}"/></td>
+					        <td class="cellltgrey">
+						        <netui:checkBox dataSource="actionForm.bannerOpt"/>
+					        </td>
+					    </tr>
+					</table>
+					
+	                </td>
+	            </tr>
+	            <tr>
+	                <td>
+		                <center>
+				        <netui:button value="${bundle.view.buttonSubmit}" />
+				        </center>
+			        </td>
+			    </tr>
+		</table> 
+		</netui:form>
+		</center>
+	</netui-template:section>
 </netui-template:template>
--- incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Address.java (original)
+++ incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/Address.java Thu May 12 19:36:31 2005
@@ -35,7 +35,7 @@
 	  WebResponse resp = Util.navToAddresses();
 	  
 	  // Make sure things look ok
-	  assertNotNull(resp.getTableWithID("addresses"));
+  	  assertTrue( resp.getTitle().contains(Util.getBundle("view", "addresses")) );
    }
 
    public void testAddAddress() throws Exception 
@@ -47,8 +47,8 @@
 	  // Sign in and go to addresses
 	  WebResponse resp = Util.navToAddresses();
 
-	  // Click the add button
-	  resp = resp.getFormWithID("addAddress").submit();
+	  // Click the add link
+	  resp = resp.getLinkWith(Util.getBundle("view", "buttonAddAddress")).click();
 	  
 	  // Enter the new data in the form
 	  WebForm form = resp.getForms()[1];
@@ -70,18 +70,18 @@
 	  resp = form.submit();
 	  
 	  // Make sure the address took
-	  WebTable table = resp.getTableWithID("addresses");
+	  WebTable table = resp.getTableWithID("address_TestAddress");
 	  assertNotNull(table);
-	  TableCell cell = table.getTableCellWithID("address_TestAddress");
+	  TableCell cell = table.getTableCell(0, 0);
 	  assertNotNull(cell);
-	  assertTrue(cell.asText().contains("TestAddress"));
-	  assertTrue(cell.asText().contains("1234 Main Street"));
-	  assertTrue(cell.asText().contains("Apt 123"));
-	  assertTrue(cell.asText().contains("Seattle"));
-	  assertTrue(cell.asText().contains("WA"));
-	  assertTrue(cell.asText().contains("98104"));
-	  assertTrue(cell.asText().contains("USA"));
-	  assertTrue(cell.asText().contains("206-333-1234"));	  
+	  assertTrue(cell.getText().contains("TestAddress"));
+	  assertTrue(cell.getText().contains("1234 Main Street"));
+	  assertTrue(cell.getText().contains("Apt 123"));
+	  assertTrue(cell.getText().contains("Seattle"));
+	  assertTrue(cell.getText().contains("WA"));
+	  assertTrue(cell.getText().contains("98104"));
+	  assertTrue(cell.getText().contains("USA"));
+	  assertTrue(cell.getText().contains("206-333-1234"));	  
    }
    
    public void testEditAddress() throws Exception 
@@ -94,9 +94,9 @@
 	  WebResponse resp = Util.navToAddresses();
 
 	  // Get the newly added address
-	  WebTable table = resp.getTableWithID("addresses");
+	  WebTable table = resp.getTableWithID("address_TestAddress");
 	  assertNotNull(table);
-	  TableCell cell = table.getTableCellWithID("address_TestAddress");
+	  TableCell cell = table.getTableCell(0, 0);
 	  assertNotNull(cell);
 	  
 	  // Edit the address by clicking the edit link
@@ -122,18 +122,18 @@
 	  resp = form.submit();
 	  
 	  // Make sure the address took
-	  table = resp.getTableWithID("addresses");
+	  table = resp.getTableWithID("address_EditedTestAddress");
 	  assertNotNull(table);
-	  cell = table.getTableCellWithID("address_EditedTestAddress");
+	  cell = table.getTableCell(0, 0);
 	  assertNotNull(cell);
-	  assertTrue(cell.asText().contains("EditedTestAddress"));
-	  assertTrue(cell.asText().contains("543 Main Street"));
-	  assertTrue(cell.asText().contains("Unit 345"));
-	  assertTrue(cell.asText().contains("Portland"));
-	  assertTrue(cell.asText().contains("OR"));
-	  assertTrue(cell.asText().contains("98799"));
-	  assertTrue(cell.asText().contains("USA2"));
-	  assertTrue(cell.asText().contains("208-222-3456"));	  
+	  assertTrue(cell.getText().contains("EditedTestAddress"));
+	  assertTrue(cell.getText().contains("543 Main Street"));
+	  assertTrue(cell.getText().contains("Unit 345"));
+	  assertTrue(cell.getText().contains("Portland"));
+	  assertTrue(cell.getText().contains("OR"));
+	  assertTrue(cell.getText().contains("98799"));
+	  assertTrue(cell.getText().contains("USA2"));
+	  assertTrue(cell.getText().contains("208-222-3456"));	  
    }
    
    public void testRemoveAddress() throws Exception 
@@ -142,18 +142,16 @@
 	  WebResponse resp = Util.navToAddresses();
 
 	  // Get the newly added address
-	  WebTable table = resp.getTableWithID("addresses");
+	  WebTable table = resp.getTableWithID("address_EditedTestAddress");
 	  assertNotNull(table);
-	  TableCell cell = table.getTableCellWithID("address_EditedTestAddress");
+	  TableCell cell = table.getTableCell(0, 0);
 	  assertNotNull(cell);
 	  
 	  // Click the remove link
 	  resp = cell.getLinkWith(Util.getBundle("view", "buttonRemove")).click();
 	  
 	  // Make sure it's gone
-	  table = resp.getTableWithID("addresses");
-	  assertNotNull(table);
-	  cell = table.getTableCellWithID("address_EditedTestAddress");
-	  assertNull(cell);
+	  table = resp.getTableWithID("address_EditedTestAddress");
+	  assertNull(table);
    }
 }

Modified: incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/AllTests.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/samples/petstoreWeb/test-src/org/apache/beehive/samples/petstore/test/AllTests.java?rev=169920&r1=169919&r2=169920&view=diff
==============================================================================